[−][src]Enum miniscript::descriptor::Descriptor
Script descriptor
Variants
Bare(Miniscript<P>)A raw scriptpubkey (including pay-to-pubkey)
Pkh(P)Pay-to-PubKey-Hash
Wpkh(P)Pay-to-Witness-PubKey-Hash
ShWpkh(P)Pay-to-Witness-PubKey-Hash inside P2SH
Sh(Miniscript<P>)Pay-to-ScriptHash
Wsh(Miniscript<P>)Pay-to-Witness-ScriptHash
ShWsh(Miniscript<P>)P2SH-P2WSH
Methods
impl<P> Descriptor<P>[src]
pub fn translate<F, Q, E>(&self, translatefn: F) -> Result<Descriptor<Q>, E> where
F: FnMut(&P) -> Result<Q, E>, [src]
F: FnMut(&P) -> Result<Q, E>,
Convert a descriptor using abstract keys to one using specific keys
impl<P: Clone> Descriptor<P>[src]
pub fn abstract_policy(&self) -> AbstractPolicy<P>[src]
Abstract the script into an "abstract policy" which can be filtered and analyzed
impl<P: ToPublicKey> Descriptor<P>[src]
pub fn address(&self, network: Network) -> Option<Address>[src]
Computes the Bitcoin address of the descriptor, if one exists
pub fn script_pubkey(&self) -> Script[src]
Computes the scriptpubkey of the descriptor
pub fn witness_script(&self) -> Script[src]
Computes the "witness script" of the descriptor, i.e. the underlying
script before any hashing is done. For Bare, Pkh and Wpkh this
is the scriptPubkey; for ShWpkh and Sh this is the redeemScript;
for the others it is the witness script.
pub fn satisfy<F, H>(
&self,
txin: &mut TxIn,
sigfn: Option<F>,
hashfn: Option<H>,
age: u32
) -> Result<(), Error> where
F: FnMut(&P) -> Option<(Signature, SigHashType)>,
H: FnMut(Hash) -> Option<[u8; 32]>, [src]
&self,
txin: &mut TxIn,
sigfn: Option<F>,
hashfn: Option<H>,
age: u32
) -> Result<(), Error> where
F: FnMut(&P) -> Option<(Signature, SigHashType)>,
H: FnMut(Hash) -> Option<[u8; 32]>,
Attempts to produce a satisfying witness or scriptSig, as the case may be,
for the descriptor, and add it to a TxIn object in the appropriate place
pub fn max_satisfaction_weight(&self) -> usize[src]
Computes an upper bound on the weight of a satisfying witness to the transaction. Assumes all signatures are 72 bytes, including push opcode and sighash suffix. Includes the weight of the VarInts encoding the scriptSig and witness stack length.