[−][src]Enum miniscript::descriptor::InterpreterError
Detailed Error type for Interpreter
Variants
Unexpected Stack End, caused by popping extra elements from stack
Unexpected Stack Push StackElement::Push element when the interpreter
was expecting a stack boolean StackElement::Satisfied or
StackElement::Dissatisfied
Verify expects stack top element exactly to be StackElement::Satisfied.
This error is raised even if the stack top is StackElement::Push.
MultiSig missing at least 1 witness elements out of k + 1 required
MultiSig requires 1 extra zero element apart from the k signatures
Script abortion because of incorrect dissatisfaction for multisig. Any input witness apart from sat(0 sig ...) or nsat(0 0 ..) leads to this error. This is network standardness assumption and miniscript only supports standard scripts
InvalidSignature(PublicKey)Signature failed to verify
General Interpreter error.
PkEvaluationError(PublicKey)Script abortion because of incorrect dissatisfaction for Checksig. Any input witness apart from sat(sig) or nsat(0) leads to this error. This is network standardness assumption and miniscript only supports standard scripts
Miniscript requires the entire top level script to be satisfied.
The Public Key hash check for the given pubkey. This occurs in PkH
node when the given key does not match to Hash in script.
Parse Error while parsing a StackElement::Push as a Pubkey. Both
33 byte and 65 bytes are supported.
The preimage to the hash function must be exactly 32 bytes.
Got StackElement::Satisfied or StackElement::Dissatisfied when the
interpreter was expecting StackElement::Push
RelativeLocktimeNotMet(u32)Could not satisfy, relative locktime not met
AbsoluteLocktimeNotMet(u32)Could not satisfy, absolute locktime not met
Forward-secp related errors