Struct miniscript::descriptor::Bare

source ·
pub struct Bare<Pk: MiniscriptKey> { /* private fields */ }
Create a Bare Descriptor. That is descriptor that is not wrapped in sh or wsh. This covers the Pk descriptor

Implementations

source

impl<Pk: MiniscriptKey> Bare<Pk>

source

pub fn new(ms: Miniscript<Pk, BareCtx>) -> Result<Self, Error>

Create a new raw descriptor

source

pub fn into_inner(self) -> Miniscript<Pk, BareCtx>

get the inner

source

pub fn as_inner(&self) -> &Miniscript<Pk, BareCtx>

get the inner

source

impl<Pk: MiniscriptKey + ToPublicKey> Bare<Pk>

source

pub fn spk(&self) -> Script

Obtain the corresponding script pubkey for this descriptor Non failing verion of DescriptorTrait::script_pubkey for this descriptor

source

pub fn inner_script(&self) -> Script

Obtain the underlying miniscript for this descriptor Non failing verion of DescriptorTrait::explicit_script for this descriptor

source

pub fn ecdsa_sighash_script_code(&self) -> Script

Obtain the pre bip-340 signature script code for this descriptor Non failing verion of DescriptorTrait::script_code for this descriptor