ParseThresholdError

Enum ParseThresholdError 

pub enum ParseThresholdError {
    NoChildren,
    KNotTerminal,
    IllegalOr,
    IllegalAnd,
    ParseK(ParseNumError),
    Threshold(ThresholdError),
}
Error parsing a threshold expression.

Variants



NoChildren

Expression had no children, not even a threshold value.



KNotTerminal

The threshold value appeared to be a sub-expression rather than a number.



IllegalOr

A 1-of-n threshold was used in a context it was not allowed.



IllegalAnd

A n-of-n threshold was used in a context it was not allowed.



ParseK(ParseNumError)

Failed to parse the threshold value.



Threshold(ThresholdError)

Threshold parameters were invalid.