Module psbt

Module psbt 

Partially-Signed Bitcoin Transactions

This module implements the Finalizer and Extractor roles defined in BIP 174, PSBT, described at https://github.com/bitcoin/bips/blob/master/bip-0174.mediawiki

Structs

PsbtInputSatisfier
Psbt satisfier for at inputs at a particular index.

Enums

Error
Error type for entire Psbt
InputError
Error type for Pbst Input
OutputUpdateError
Return error type for PsbtExt::update_output_with_descriptor
PsbtSighashMsg
Sighash message(signing data) for a given psbt transaction input.
SighashError
Return error type for PsbtExt::sighash_msg
UtxoUpdateError
Return error type for PsbtExt::update_input_with_descriptor

Traits

PsbtExt
Additional operations for miniscript descriptors for various psbt roles. Note that these APIs would generally error when used on scripts that are not miniscripts.
PsbtInputExt
Extension trait for PSBT inputs
PsbtOutputExt
Extension trait for PSBT outputs

Functions

finalizeDeprecated
Finalize the psbt.
finalize_mall
Same as finalize, but allows for malleable satisfactions
interpreter_check
Interprets all psbt inputs and checks whether the script is correctly interpreted according to the context.