Partially-Signed Bitcoin Transactions
This module implements the Finalizer and Extractor roles defined in
BIP 174, PSBT, described at
https://github.com/bitcoin/bips/blob/master/bip-0174.mediawiki
Structs
- Psbt
Input Satisfier - Psbt satisfier for at inputs at a particular index.
Enums
- Error
- Error type for entire Psbt
- Input
Error - Error type for Pbst Input
- Output
Update Error - Return error type for
PsbtExt::update_output_with_descriptor - Psbt
Sighash Msg - Sighash message(signing data) for a given psbt transaction input.
- Sighash
Error - Return error type for
PsbtExt::sighash_msg - Utxo
Update Error - Return error type for
PsbtExt::update_input_with_descriptor
Traits
- PsbtExt
- Additional operations for miniscript descriptors for various psbt roles. Note that these APIs would generally error when used on scripts that are not miniscripts.
- Psbt
Input Ext - Extension trait for PSBT inputs
- Psbt
Output Ext - Extension trait for PSBT outputs
Functions
- finalize
Deprecated - Finalize the psbt.
- finalize_
mall - Same as finalize, but allows for malleable satisfactions
- interpreter_
check - Interprets all psbt inputs and checks whether the script is correctly interpreted according to the context.